==> mapmyindia_gl-0.2.0.tar.gz: example/lib/samples/geocode_widget.dart <==

import 'dart:typed_data';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:mapmyindia_gl/mapmyindia_gl.dart';
import 'package:mapmyindia_gl_example/utils/color.dart';

class GeocodeWidget extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return GeocodeWidgetState();
  }

}
class GeocodeWidgetState extends State {
  static final CameraPosition _kInitialPosition = const CameraPosition(
    target: LatLng(25.321684, 82.987289),
    zoom: 10.0,
  );

  late MapmyIndiaMapController controller;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        centerTitle: true,
        backgroundColor: MyColor.colorPrimary,
        brightness: Brightness.dark,
        title: Text(
          'Geocoding API',
          style: TextStyle(color: Colors.white),
        ),
        elevation: 0.2,
      ),
      body: MapmyIndiaMap(
        initialCameraPosition: _kInitialPosition,
        onMapCreated: (map) =>
        {
          controller = map,
        },
        onStyleLoadedCallback: () => {
          callGeocode()
        },
      ),
    );
  }


  void addMarker(LatLng latLng) async {
    controller.addSymbol(SymbolOptions(geometry: latLng));
    controller.animateCamera(CameraUpdate.newLatLngZoom(latLng, 14));
  }

  callGeocode() async{
    try {
      GeocodeResponse? response = await MapmyIndiaGeoCoding(address: "Saket")
          .callGeocoding();
      if (response != null && response.results != null &&
          response.results!.length > 0) {
        addMarker(LatLng(
            response.results![0].latitude!, response.results![0].longitude!));
      }
    } catch(e) {
      if (e is PlatformException) {
        Fluttertoast.showToast(msg: '${e.code} --- ${e.message}');
      }
    }
  }

}

==> mapmyindia_gl-0.3.2.tar.gz: example/lib/samples/geocode_widget.dart <==

import 'dart:typed_data';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:mapmyindia_gl/mapmyindia_gl.dart';
import 'package:mapmyindia_gl_example/utils/color.dart';

class GeocodeWidget extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return GeocodeWidgetState();
  }

}
class GeocodeWidgetState extends State {
  static final CameraPosition _kInitialPosition = const CameraPosition(
    target: LatLng(25.321684, 82.987289),
    zoom: 10.0,
  );

  late MapmyIndiaMapController controller;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        centerTitle: true,
        backgroundColor: MyColor.colorPrimary,
        brightness: Brightness.dark,
        title: Text(
          'Geocoding API',
          style: TextStyle(color: Colors.white),
        ),
        elevation: 0.2,
      ),
      body: MapmyIndiaMap(
        initialCameraPosition: _kInitialPosition,
        onMapCreated: (map) =>
        {
          controller = map,
        },
        onStyleLoadedCallback: () => {
          callGeocode()
        },
      ),
    );
  }


  void addMarker(LatLng latLng) async {
    controller.addSymbol(SymbolOptions(geometry: latLng));
    controller.animateCamera(CameraUpdate.newLatLngZoom(latLng, 14));
  }

  callGeocode() async{
    try {
      GeocodeResponse? response = await MapmyIndiaGeoCoding(address: "Saket", bias: GeocodingCriteria.BIAS_RURAL)
          .callGeocoding();
      print(response?.toJson());
      if (response != null && response.results != null &&
          response.results!.length > 0) {
        addMarker(LatLng(
            response.results![0].latitude!, response.results![0].longitude!));
      }
    } catch(e) {
      if (e is PlatformException) {
        Fluttertoast.showToast(msg: '${e.code} --- ${e.message}');
      }
    }
  }

}
